#' ---
#' S. Yalcin, S.J Leroux. [in review]. An empirical test of the relative and combined effects of land-cover and climate change on species range shifts.
#' title: "Regional colonization and extinction rate & species traits"
#' author: "Semra Yalcin"
#' Contact: "Semra Yalcin", "syalcin@mun.ca"
#' date: "August, 2017"
#' ---
#' ### Load datasets
#' 
## ------------------------------------------------------------------------

TraitSPs_G <- read.csv("./3_b_TraitSPs_G.csv")

TraitSPs_L <- read.csv("./3_c_TraitSPs_L.csv")

#' 
#' Figure S2.
#' 
## ------------------------------------------------------------------------
library(ggplot2)

l1 <- ggplot(TraitSPs_L, aes(x = factor(Habitat), y = LossRate)) + 
    #geom_boxplot(fill="grey99", alpha=0.5, size=0.75) +  
    #geom_violin()+
    geom_jitter(width = 0.45, size=3)+
    scale_fill_identity(name="", guide="legend", labels=c("Migration")) + 
    expand_limits(y=0) +
    labs(x="Habitat preference", y="Loss rate") +  
    theme_GCB()+
    theme(legend.position="bottom")+ 
    stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median, geom = "crossbar", width = 0.5, color="blue")

l2 <- ggplot(TraitSPs_L, aes(x = factor(Migration), y = LossRate)) + 
    #geom_boxplot(fill="grey99", alpha=0.5, size=0.75) +  
    #geom_violin()+
    geom_jitter(width = 0.45, size=3)+
    scale_fill_identity(name="", guide="legend", labels=c("Migration")) + 
    expand_limits(y=0) +
    labs(x="Migration", y="Loss rate") +  
     theme_GCB()+
    theme(legend.position="bottom")+
    stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median, geom = "crossbar", width = 0.5, color="blue")


l3 <- ggplot(TraitSPs_L, aes(x=log(MBM), y=LossRate)) +
  geom_point(size=3)+
  labs(x="log(mean body mass (g))", y="Loss rate") +  
     theme_GCB()+
  theme(legend.position="bottom")+
  geom_smooth(method = "lm", se = FALSE)


multiplot(l1, l2, l3, nrow=1)


g1 <- ggplot(TraitSPs_G, aes(x = factor(Habitat), y = GainRate)) + 
    #geom_boxplot(fill="grey99", alpha=0.5, size=0.75) +
    #geom_violin()+
    geom_jitter(width = 0.45, size=3)+
    scale_fill_identity(name="", guide="legend", labels=c("Migration")) + 
    expand_limits(y=0) +
    labs(x="Habitat preference", y="Gain rate") +  
    theme_GCB()+
    theme(legend.position="bottom")+
    stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median, geom = "crossbar", width = 0.5, color="blue")

g2 <- ggplot(TraitSPs_G, aes(x = factor(Migration), y = GainRate)) + 
    #geom_boxplot(fill="grey99", alpha=0.5, size=0.75) +
    #geom_violin()+
    geom_jitter(width = 0.45, size=3)+
    scale_fill_identity(name="", guide="legend", labels=c("Migration")) + 
    expand_limits(y=0) +
    labs(x="Migration", y="Gain rate") +  
    theme_GCB()+
    theme(legend.position="bottom")+
  stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median, geom = "crossbar", width = 0.5, color="blue")

g3 <- ggplot(TraitSPs_G, aes(x=log(MBM), y=GainRate)) +
  geom_point(size=3)+
  labs(x="log(mean body mass (g))", y="Gain rate") +  
  theme_GCB()+
  theme(legend.position="bottom")+
  geom_smooth(method = "lm", se = FALSE)

multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)

  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)

  numPlots = length(plots)

  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                    ncol = cols, nrow = ceiling(numPlots/cols))
  }

 if (numPlots==1) {
    print(plots[[1]])

  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))

    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))

      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}

multiplot(g1, g2, g3, nrow=1)

#' 
#' MODELS
#' 
#' ### Extinction rate (L/L+PP)
#' 
## ---- tidy.opts = list(width.cutoff = 60), tidy=TRUE, message=F, warning=F, echo=T----
# Model set
Cand.models.l <- list( )
Cand.models.l[[1]] <- lm(LossRate ~ log(MBM) , data=TraitSPs_L)
Cand.models.l[[2]] <- lm(LossRate ~ factor(Habitat), data=TraitSPs_L)
Cand.models.l[[3]] <- lm(LossRate ~ factor(Migration), data=TraitSPs_L)
Cand.models.l[[4]] <- lm(LossRate ~ log(MBM) + factor(Habitat), data=TraitSPs_L)
Cand.models.l[[5]] <- lm(LossRate ~ factor(Habitat) + factor(Migration) , data=TraitSPs_L)
Cand.models.l[[6]] <- lm(LossRate ~ factor(Habitat) * factor(Migration) , data=TraitSPs_L)
Cand.models.l[[7]] <- lm(LossRate ~ log(MBM) + factor(Migration) , data=TraitSPs_L)
Cand.models.l[[8]] <- lm(LossRate ~ log(MBM) + factor(Habitat) + factor(Migration), data=TraitSPs_L)
Cand.models.l[[9]] <- lm(LossRate ~ log(MBM) * factor(Habitat) * factor(Migration), data=TraitSPs_L)
Cand.models.l[[10]] <- lm(LossRate ~ 1, data=TraitSPs_L)

# Name of models
Modnames <- c("m1", "m2", "m3", "m4","m5", "m6", "m7", "m8", "m9", "m10")

# AIC table
library(AICcmodavg)
AIC_loss <- aictab(cand.set = Cand.models.l, modnames = Modnames, sort = TRUE)

LM_1_l <- lm(LossRate ~ log(MBM), data=TraitSPs_L)
LM_2_l <- lm(LossRate ~ factor(Habitat), data=TraitSPs_L)
LM_3_l <- lm(LossRate ~ factor(Migration), data=TraitSPs_L)
LM_4_l <- lm(LossRate ~ log(MBM) + factor(Habitat), data=TraitSPs_L)
LM_5_l <- lm(LossRate ~ factor(Habitat) + factor(Migration) , data=TraitSPs_L)
LM_6_l <- lm(LossRate ~ factor(Habitat) * factor(Migration) , data=TraitSPs_L)
LM_7_l <- lm(LossRate ~ log(MBM) + factor(Migration) , data=TraitSPs_L)
LM_8_l <- lm(LossRate ~ log(MBM) + factor(Habitat) + factor(Migration), data=TraitSPs_L)
LM_9_l <- lm(LossRate ~ log(MBM) * factor(Habitat) * factor(Migration), data=TraitSPs_L)
LM_10_l  <- lm(LossRate ~ 1, data=TraitSPs_L)

R_loss<-matrix(nrow=10,ncol=1);rownames(R_loss)<-c("LM_1", "LM_2", "LM_3", "LM_4", "LM_5", "LM_6", "LM_7", "LM_8", "LM_9", "LM_10"); colnames(R_loss)<-c("R^2")

R_loss[1,1] <-summary(LM_1_l)$r.squared
R_loss[2,1] <-summary(LM_2_l)$r.squared
R_loss[3,1] <-summary(LM_3_l)$r.squared
R_loss[4,1] <-summary(LM_4_l)$r.squared
R_loss[5,1] <-summary(LM_5_l)$r.squared
R_loss[6,1] <-summary(LM_6_l)$r.squared
R_loss[7,1] <-summary(LM_7_l)$r.squared
R_loss[8,1] <-summary(LM_8_l)$r.squared
R_loss[9,1] <-summary(LM_9_l)$r.squared
R_loss[10,1] <-summary(LM_10_l)$r.squared

cbind(AIC_loss, R_loss)

loss_table <- cbind(AIC_loss, R_loss)
mean(loss_table$`R^2`)

#' 
#' 
#' ### Colonization rate (G/L+PP)
#' 
## ---- tidy.opts = list(width.cutoff = 60), tidy=TRUE, message=F, warning=F, echo=T----
# Model set
Cand.models.g <- list( )
Cand.models.g[[1]] <- lm(GainRate ~ log(MBM) , data=TraitSPs_G)
Cand.models.g[[2]] <- lm(GainRate ~ factor(Habitat), data=TraitSPs_G)
Cand.models.g[[3]] <- lm(GainRate ~ factor(Migration), data=TraitSPs_G)
Cand.models.g[[4]] <- lm(GainRate ~ log(MBM) + factor(Habitat), data=TraitSPs_G)
Cand.models.g[[5]] <- lm(GainRate ~ factor(Habitat) + factor(Migration) , data=TraitSPs_G)
Cand.models.g[[6]] <- lm(GainRate ~ factor(Habitat) * factor(Migration) , data=TraitSPs_G)
Cand.models.g[[7]] <- lm(GainRate ~ log(MBM) + factor(Migration) , data=TraitSPs_G)
Cand.models.g[[8]] <- lm(GainRate ~ log(MBM) + factor(Habitat) + factor(Migration), data=TraitSPs_G)
Cand.models.g[[9]] <- lm(GainRate ~ log(MBM) * factor(Habitat) * factor(Migration), data=TraitSPs_G)

# Name of models
Modnames <- c("m1", "m2", "m3", "m4","m5", "m6", "m7", "m8", "m9")

# AIC table
library(AICcmodavg)
AIC_gain <- aictab(cand.set = Cand.models.g, modnames = Modnames, sort = TRUE)

LM_1_g <- lm(GainRate ~ log(MBM), data=TraitSPs_G)
LM_2_g <- lm(GainRate ~ factor(Habitat), data=TraitSPs_G)
LM_3_g <- lm(GainRate ~ factor(Migration), data=TraitSPs_G)
LM_4_g <- lm(GainRate ~ log(MBM) + factor(Habitat), data=TraitSPs_G)
LM_5_g <- lm(GainRate ~ factor(Habitat) + factor(Migration) , data=TraitSPs_G)
LM_6_g <- lm(GainRate ~ factor(Habitat) * factor(Migration) , data=TraitSPs_G)
LM_7_g <- lm(GainRate ~ log(MBM) + factor(Migration) , data=TraitSPs_G)
LM_8_g <- lm(GainRate ~ log(MBM) + factor(Habitat) + factor(Migration), data=TraitSPs_G)
LM_9_g <- lm(GainRate ~ log(MBM) * factor(Habitat) * factor(Migration), data=TraitSPs_G)

R_gain<-matrix(nrow=9,ncol=1);rownames(R_gain)<-c("LM_1", "LM_2", "LM_3", "LM_4", "LM_5", "LM_6", "LM_7", "LM_8", "LM_9"); colnames(R_gain)<-c("R^2")

R_gain[1,1] <-summary(LM_1_g)$r.squared
R_gain[2,1] <-summary(LM_2_g)$r.squared
R_gain[3,1] <-summary(LM_3_g)$r.squared
R_gain[4,1] <-summary(LM_4_g)$r.squared
R_gain[5,1] <-summary(LM_5_g)$r.squared
R_gain[6,1] <-summary(LM_6_g)$r.squared
R_gain[7,1] <-summary(LM_7_g)$r.squared
R_gain[8,1] <-summary(LM_8_g)$r.squared
R_gain[9,1] <-summary(LM_9_g)$r.squared


cbind(AIC_gain, R_gain)

gain_table <- cbind(AIC_gain, R_gain)
mean(gain_table$`R^2`)


#' 
